@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::File::MinSize;
 
-use strict;
-use base 'HTML::FormFu::Constraint::File::Size';
+use Moose;
+extends 'HTML::FormFu::Constraint::File::Size';
 
 sub _localize_args {
     my ($self) = @_;
@@ -9,6 +9,8 @@ sub _localize_args {
     return $self->min;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -51,3 +53,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
