@@ -1,15 +1,25 @@
 package HTML::FormFu::Constraint::File::Size;
+use Moose;
+use MooseX::Attribute::Chained;
+use MooseX::Aliases;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+extends 'HTML::FormFu::Constraint';
 
 use Carp qw( croak );
 use Scalar::Util qw( blessed );
 
-__PACKAGE__->mk_item_accessors(qw( minimum maximum ));
+has minimum => (
+    is      => 'rw',
+    alias   => 'min',
+    traits  => ['Chained'],
+);
+
+has maximum => (
+    is      => 'rw',
+    alias   => 'max',
+    traits  => ['Chained'],
+);
 
-*min          = \&minimum;
-*max          = \&maximum;
 *min_kilobyte = \&minimum_kilobyte;
 *max_kilobyte = \&maximum_kilobyte;
 *min_megabyte = \&minimum_megabyte;
@@ -80,6 +90,8 @@ sub maximum_megabyte {
     return $self->maximum( $kb * 1_048_576 );
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -160,3 +172,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
