@@ -1,36 +1,14 @@
 package HTML::FormFu::Model;
+use Moose;
+use MooseX::Attribute::Chained;
 
-use strict;
-use mro 'c3';
+with 'HTML::FormFu::Role::HasParent';
 
-use HTML::FormFu::Attribute qw( mk_accessors mk_item_accessors );
 use HTML::FormFu::ObjectUtil qw( form parent );
 use Scalar::Util qw( refaddr reftype );
 use Carp qw( croak );
 
-__PACKAGE__->mk_item_accessors(qw( type ));
-
-sub new {
-    my $class = shift;
-    my %attrs;
-    
-    if (@_) {
-        croak "attributes argument must be a hashref"
-            if reftype( $_[0] ) ne 'HASH';
-        
-        %attrs = %{ $_[0] };
-    }
-    
-    my $self = bless {}, $class;
-
-    for my $arg (qw( parent type )) {
-        croak "$arg attribute required" if !exists $attrs{$arg};
-
-        $self->$arg( $attrs{$arg} );
-    }
-
-    return $self;
-}
+has type => ( is => 'rw', traits  => ['Chained'] );
 
 sub default_values {
     croak "'default_values' method not implemented by Model class";
@@ -56,6 +34,8 @@ sub clone {
     return bless \%new, ref $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
